==> ejc-supbid-api-3.0.1-20211123.065828-3-sources.jar: com/ejianc/business/supbid/notice/vo/BmNoticeVO.java <==
package com.ejianc.business.supbid.notice.vo;

import com.ejianc.business.supbid.material.vo.DetailVO;
import com.ejianc.business.supbid.material.vo.SchemeVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 报名数据实体
 * 
 * @author sunyj
 * 
 */
@ApiModel("报名数据实体")
public class BmNoticeVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("来源租户ID")
    private String sourceTenantId;
    @ApiModelProperty("来源ID-招标主键")
    private String sourceId;
    @ApiModelProperty("当前租户主键")
    private String tenantId;
    @ApiModelProperty("供应商主键")
    private String supplierId;
    @ApiModelProperty("报名联系人")
    private Long employeeId;
    @ApiModelProperty("报名联系人名称")
    private String employeeName;
    @ApiModelProperty("报名联系人电话")
    private String employeeMobile;
    @ApiModelProperty("报名时间")
    private java.util.Date signTime;
    @ApiModelProperty("报名操作人")
    private java.lang.Long signId;
    @ApiModelProperty("报名操作人名称")
    private java.lang.Long signName;

    public String getSourceTenantId() {
        return sourceTenantId;
    }

    public void setSourceTenantId(String sourceTenantId) {
        this.sourceTenantId = sourceTenantId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getEmployeeMobile() {
        return employeeMobile;
    }

    public void setEmployeeMobile(String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }

    public Date getSignTime() {
        return signTime;
    }

    public void setSignTime(Date signTime) {
        this.signTime = signTime;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public Long getSignName() {
        return signName;
    }

    public void setSignName(Long signName) {
        this.signName = signName;
    }
}

==> ejc-supbid-api-3.0.1-20211124.015809-6-sources.jar: com/ejianc/business/supbid/notice/vo/BmNoticeVO.java <==
package com.ejianc.business.supbid.notice.vo;

import com.ejianc.business.supbid.material.vo.DetailVO;
import com.ejianc.business.supbid.material.vo.SchemeVO;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 报名数据实体
 * 
 * @author sunyj
 * 
 */
@ApiModel("报名数据实体")
public class BmNoticeVO {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("来源租户ID")
    private String sourceTenantId;
    @ApiModelProperty("来源ID-招标主键")
    private String sourceId;
    @ApiModelProperty("当前租户主键")
    private String tenantId;
    @ApiModelProperty("供应商主键")
    private String supplierId;
    @ApiModelProperty("报名联系人")
    private Long employeeId;
    @ApiModelProperty("报名联系人名称")
    private String employeeName;
    @ApiModelProperty("报名联系人电话")
    private String employeeMobile;
    @ApiModelProperty("报名时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private java.util.Date signTime;
    @ApiModelProperty("报名操作人")
    private java.lang.Long signId;
    @ApiModelProperty("报名操作人名称")
    private java.lang.Long signName;

    public String getSourceTenantId() {
        return sourceTenantId;
    }

    public void setSourceTenantId(String sourceTenantId) {
        this.sourceTenantId = sourceTenantId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(String supplierId) {
        this.supplierId = supplierId;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getEmployeeMobile() {
        return employeeMobile;
    }

    public void setEmployeeMobile(String employeeMobile) {
        this.employeeMobile = employeeMobile;
    }

    public Date getSignTime() {
        return signTime;
    }

    public void setSignTime(Date signTime) {
        this.signTime = signTime;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public Long getSignName() {
        return signName;
    }

    public void setSignName(Long signName) {
        this.signName = signName;
    }
}
